@@ -6,7 +6,7 @@ import FormNumberInput from '../../components/style/form-number-input';
 const tableStyle = {width: "100%", borderSpacing: "2px 0", marginBottom: "2px"};
 const firstTdStyle = {width: '6em'};
 
-export default function PropertyNumber({value, onUpdate, configs, sourceElement, internalState, state}) {
+export default function PropertyNumber({value, onUpdate, onValid, configs, sourceElement, internalState, state}) {
 
   let update = (val) => {
     let number = parseFloat(val);
@@ -33,6 +33,7 @@ export default function PropertyNumber({value, onUpdate, configs, sourceElement,
           <FormNumberInput
             value={value}
             onChange={event => update(event.target.value)}
+            onValid={onValid}
             min={configs.min}
             max={configs.max}/>
         </td>
@@ -46,6 +47,7 @@ export default function PropertyNumber({value, onUpdate, configs, sourceElement,
 PropertyNumber.propTypes = {
   value: PropTypes.any.isRequired,
   onUpdate: PropTypes.func.isRequired,
+  onValid: PropTypes.func,
   configs: PropTypes.object.isRequired,
   sourceElement: PropTypes.object,
   internalState: PropTypes.object,
